
## CATO-CLI - mutation.site.removeSecondaryAwsVSocket:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.site.removeSecondaryAwsVSocket) for documentation on this operation.

### Usage for mutation.site.removeSecondaryAwsVSocket:

`catocli mutation site removeSecondaryAwsVSocket -h`

`catocli mutation site removeSecondaryAwsVSocket <json>`

`catocli mutation site removeSecondaryAwsVSocket "$(cat < mutation.site.removeSecondaryAwsVSocket.json)"`

`catocli mutation site removeSecondaryAwsVSocket '{"socketId":"id"}'`

`catocli mutation site removeSecondaryAwsVSocket -p '{
    "socketId": "id"
}'`


#### Operation Arguments for mutation.site.removeSecondaryAwsVSocket ####

`accountId` [ID] - (required) N/A    
`socketId` [ID] - (required) N/A    
